#
# spec file for package python-pdfrw
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# Tests require external files
%bcond_with     test
%{?sle15_python_module_pythons}
Name:           python-pdfrw
Version:        0.4
Release:        5.1
Summary:        PDF file reader/writer library
License:        MIT
Group:          Development/Libraries/Python
URL:            https://code.google.com/p/pdfrw/
Source:         https://files.pythonhosted.org/packages/source/p/pdfrw/pdfrw-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%if %{with test}
BuildRequires:  %{python_module pytest}
%endif
%python_subpackages

%description
pdfrw is a Python library and utility that reads and writes PDF files.

%prep
%setup -q -n pdfrw-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%if %{with test}
%check
%pytest
%endif

%files %{python_files}
%license LICENSE.txt
%doc README.rst
%{python_sitelib}/pdfrw/
%{python_sitelib}/pdfrw-%{version}*-info

%changelog
* Tue Jun  3 2025 Markéta Machová <mmachova@suse.com>
- Convert to pip-based build
* Fri Aug 25 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Thu Mar  7 2019 Tomáš Chvátal <tchvatal@suse.com>
- Fix fdupes call
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Wed Oct 18 2017 toddrme2178@gmail.com
- Update to version 0.4
  * Python 3.6 added to test matrix
  * Proper unicode support for text strings in PDFs added
  * buildxobj fixes allow better support creating form XObjects
    out of compressed pages in some cases
  * Compression fixes for Python 3+
  * New subset_booklets.py example
  * Bug with non-compressed indices into compressed object streams fixed
  * Bug with distinguishing compressed object stream first objects fixed
  * Better error reporting added for some invalid PDFs (e.g. when reading
    past the end of file)
  * Better scrubbing of old bookmark information when writing PDFs, to
    remove dangling references
  * Refactoring of pdfwriter, including updating API, to allow future
    enhancements for things like incremental writing
  * Minor tokenizer speedup
  * Some flate decompressor bugs fixed
  * Compression and decompression tests added
  * Tests for new unicode handling added
  * PdfReader.readpages() recursion error (issue #92) fixed.
  * Initial crypt filter support added
- Update to version 0.3
  * Python 3.5 added to test matrix
  * Better support under Python 3.x for in-memory PDF file-like objects
  * Some pagemerge and Unicode patches added
  * Changes to logging allow better coexistence with other packages
  * Fix for "from pdfrw import \*"
  * New fancy_watermark.py example shows off capabilities of pagemerge.py
  * metadata.py example renamed to cat.py
- Update to version 0.2
  * Several bugs have been fixed
  * New regression test functionally tests core with dozens of
    PDFs, and also tests examples.
  * Core has been ported and tested on Python3 by round-tripping
    several difficult files and observing binary matching results
    across the different Python versions.
  * Still only minimal support for compression and no support
    for encryption or newer PDF features.  (pdftk is useful
    to put PDFs in a form that pdfrw can use.)
* Thu Aug 24 2017 jmatejek@suse.com
- singlespec auto-conversion
* Mon Jul 13 2015 toddrme2178@gmail.com
- Fix building on SLES 11
* Sat Nov  9 2013 tchvatal@suse.com
- Fix name in the header.
* Sat Nov  9 2013 tchvatal@suse.com
- Inital commit, package required by python-rst2pdf on runtime.
